#-*- coding: utf-8 -*-
u"""

.. moduleauthor:: Martí Congost <marti.congost@whads.com>
"""
from cocktail.translations import translations

translations.define("woost.extensions.webconsole.page.title",
    ca = u"Intèrpret de Python",
    es = u"Intérprete de Python",
    en = u"Python interpreter"
)

translations.define("woost.extensions.webconsole.controller.title",
    ca = u"Controlador d'intèrpret de Python",
    es = u"Controlador de intérprete de Python",
    en = u"Python interpreter controller"
)

translations.define("woost.extensions.webconsole.template.title",
    ca = u"Plantilla d'intèrpret de Python",
    es = u"Plantilla de intérprete de Python",
    en = u"Python interpreter template"
)

# WebConsolePermission
#------------------------------------------------------------------------------
translations.define("WebConsolePermission",
    ca = u"Permís d'execució de Python",
    es = u"Permiso de ejecución de Python",
    en = u"Python execution permission"
)

translations.define("WebConsolePermission-plural",
    ca = u"Permisos d'execució de Python",
    es = u"Permisos de ejecución de Python",
    en = u"Python execution permissions"
)

