
.Discount {
    border: 2px solid #2e5d24;
    background-color: #d4dfd1;
    overflow: hidden;
    -moz-border-radius: 0.4em;
    -webkit-border-radius: 0.4em;
    -webkit-box-shadow: 2px 2px 2px #b5c5b4;
    max-width: 30em;
    font-size: 0.9em;
}

.Discount .value_label {
    color: white;
    background-color: #2e5d24;
    padding: 0.2em;
    font-size: 1.1em;
    font-family: Arial Black;
}

.Discount .description {
    padding: 0.4em;
    color: #131;
    max-width: 20em;
}

