#-*- coding: utf-8 -*-
"""

@author:		Martí Congost
@contact:		marti.congost@whads.com
@organization:	Whads/Accent SL
@since:			September 2009
"""
from cocktail.translations import translations

translations.define("Action sync_vimeo",
    ca = u"Sincronitzar amb Vimeo.com",
    es = u"Sincronizar con Vimeo.com",
    en = u"Synchronize with Vimeo.com"
)

translations.define("VimeoSynchronizationForm.vimeo_user_name",
    ca = u"Nom d'usuari de Vimeo",
    es = u"Nombre de usuario de Vimeo",
    en = u"Vimeo user name"
)

translations.define(
    "woost.extensions.vimeo.SynchronizationView synchronize button",
    ca = u"Sincronitzar",
    es = u"Sincronizar",
    en = u"Synchronize"
)

translations.define(
    "woost.extensions.vimeo.SynchronizationView outcome",
    ca = u"S'ha completat la sincronització amb el compte indicat.",
    es = u"Se ha completado la sincronización con la cuenta indicada.",
    en = u"Synchronization with the specified account complete."
)

translations.define(
    "woost.extensions.vimeo.SynchronizationView no changes",
    ca = u"No ha estat necessari realitzar cap actualització.",
    es = u"No ha sido necesario realizar ninguna actualización.",
    en = u"No update was needed."
)

translations.define(
    "woost.extensions.vimeo.SynchronizationView created videos title",
    ca = u"Vídeos afegits",
    es = u"Videos añadidos",
    en = u"Added videos"
)

translations.define(
    "woost.extensions.vimeo.SynchronizationView created videos explanation",
    ca = u"Els següents vídeos s'han incorporat al lloc web:",
    es = u"Los videos siguientes se han incorporado al sitio web:",
    en = u"The following videos were added to the web site:"
)

translations.define(
    "woost.extensions.vimeo.SynchronizationView modified videos title",
    ca = u"Vídeos modificats",
    es = u"Videos modificados",
    en = u"Modified videos"
)

translations.define(
    "woost.extensions.vimeo.SynchronizationView modified videos explanation",
    ca = u"S'ha actualitzat la informació dels vídeos següents:",
    es = u"Se ha actualizado la información de los videos siguientes:",
    en = u"The following videos had changes that have been reflected on the "
         u"web site:"
)

translations.define(
    "woost.extensions.vimeo.SynchronizationView deleted videos title",
    ca = u"Vídeos eliminats",
    es = u"Videos eliminados",
    en = u"Deleted videos"
)

translations.define(
    "woost.extensions.vimeo.SynchronizationView deleted videos explanation",
    ca = u"Els següents vídeos ja no són presents a vimeo.com i s'han "
         u"eliminat del lloc web:",
    es = u"Los videos siguientes ya no están disponibles en vimeo.com y se "
         u"han eliminado del sitio web:",
    en = u"The following videos are no longer available at vimeo.com and "
         u"have been deleted from the web site:"
)

translations.define("woost.extensions.vimeo.SynchronizationView cancel button",
    ca = u"Tancar",
    es = u"Cerrar",
    en = u"Close"
)

# VimeoVideo model
#------------------------------------------------------------------------------
translations.define("VimeoVideo",
    ca = u"Vídeo Vimeo",
    es = u"Video Vimeo",
    en = u"Vimeo video"
)

translations.define("VimeoVideo-plural",
    ca = u"Vídeos Vimeo",
    es = u"Videos Vimeo",
    en = u"Vimeo videos"
)

translations.define("VimeoVideo.content",
    ca = u"Contingut",
    es = u"Contenido",
    en = u"Content"
)

translations.define("VimeoVideo.video_file_data",
    ca = u"Dades del fitxer de vídeo",
    es = u"Datos del fichero de video",
    en = u"Video file data"
)

translations.define("VimeoVideo.stats",
    ca = u"Estadístiques",
    es = u"Estadísticas",
    en = u"Stats"
)

translations.define("VimeoVideo.vimeo_data",
    ca = u"Paràmetres d'allotjament",
    es = u"Parámetros de alojamiento",
    en = u"Hosting parameters"
)

translations.define("VimeoVideo.title",
    ca = u"Títol",
    es = u"Título",
    en = u"Title"
)

translations.define("VimeoVideo.description",
    ca = u"Descripció",
    es = u"Descripción",
    en = u"Description"
)

translations.define("VimeoVideo.vimeo_tags",
    ca = u"Etiquetes",
    es = u"Etiquetas",
    en = u"Tags"
)

translations.define("VimeoVideo.duration",
    ca = u"Duració",
    es = u"Duración",
    en = u"Duration"
)

translations.define("VimeoVideo.width",
    ca = u"Amplada",
    es = u"Ancho",
    en = u"Width"
)

translations.define("VimeoVideo.height",
    ca = u"Alçada",
    es = u"Alto",
    en = u"Height"
)

translations.define("VimeoVideo.approval_count",
    ca = u"Vots favorables",
    es = u"Votos favorables",
    en = u"Approval count"
)

translations.define("VimeoVideo.views_count",
    ca = u"Recompte de reproduccions",
    es = u"Recuento de reproducciones",
    en = u"Play count"
)

translations.define("VimeoVideo.comments_count",
    ca = u"Número de comentaris",
    es = u"Número de comentarios",
    en = u"Comments count"
)

translations.define("VimeoVideo.vimeo_video_id",
    ca = u"Identificador de vídeo de Vimeo",
    es = u"Identificador de video de Vimeo",
    en = u"Vimeo video ID"
)

translations.define("VimeoVideo.uri",
    ca = u"URL del vídeo",
    es = u"URL del video",
    en = u"Video URL"
)

translations.define("VimeoVideo.vimeo_user_name",
    ca = u"Nom d'usuari de Vimeo",
    es = u"Nombre de usuario de Vimeo",
    en = u"Vimeo user name"
)

translations.define("VimeoVideo.vimeo_user_url",
    ca = u"Adreça de l'usuari de Vimeo",
    es = u"Dirección del usuario de Vimeo",
    en = u"Vimeo user URL"
)

translations.define("VimeoVideo.upload_date",
    ca = u"Data de càrrega del vídeo a Vimeo",
    es = u"Fecha de carga del video en Vimeo",
    en = u"Upload date"
)

