#-*- coding: utf-8 -*-
u"""
Translated strings for the Woost CMS.

@author:		Martí Congost
@contact:		marti.congost@whads.com
@organization:	Whads/Accent SL
@since:			October 2008
"""
from woost.translations import strings

