
.BackOfficeDeleteView .block_notice {
    color: black;
    border: 1px dotted rgb(200,160,120);
    background-color: rgb(245,230,215);
    padding: 0.5em;
}

.BackOfficeDeleteView .delete_preview .ContentLink {
    text-decoration: none;
}

.BackOfficeDeleteView .delete_preview ul,
.BackOfficeDeleteView .delete_preview dl,
.BackOfficeDeleteView .delete_preview dd,
.BackOfficeDeleteView .delete_preview dt {
    list-style-type: none;
    padding: 0;
    margin: 0;
    display: block;
}

.BackOfficeDeleteView .delete_preview p {
    margin: 0;
}

.BackOfficeDeleteView .delete_preview dl {
    padding-left: 1.65em;
}

.BackOfficeDeleteView .delete_preview dt {
    font-size: 0.8em;
    font-weight: bold;
    color: rgb(75,75,75);
    margin-top: 0.7em;
    margin-bottom: 0.4em;
}

.BackOfficeDeleteView .delete_preview li {
    margin-top: 0.25em;
    margin-bottom: 0.25em;
}

.BackOfficeDeleteView .cascade_details,
.BackOfficeDeleteView .block_details {
    margin-top: 0.5em;
    margin-left: 1.5em;
}

.BackOfficeDeleteView .details_label {
    font-size: 0.8em;
    font-weight: bold;
    display: inline-block;
    background-repeat: no-repeat;
    background-position: 0.1em center;
    padding: 0.4em 0.2em;
    padding-left: 2em;
}

.BackOfficeDeleteView .block_details > .details_label {
    color: #7c0303;
    background-color: rgb(245,230,215);
    border: 1px dotted rgb(200,160,120);
    background-image: url(../images/error.png);
}

.BackOfficeDeleteView .cascade_details > .details_label {
    color: #7c5303;
    background-color: #f7eaa9;
    border: 1px dotted #ead87d;
    background-image: url(../images/warning.png);
}

.BackOfficeDeleteView .cascade_details .cascade_details .details_label {
    display: none;
}

.BackOfficeDeleteView .cascade_details .cascade_details dl {
    padding-left: 0;
}

