
.EditPanel {
    font-size: 0.85em;
}

.EditPanel .block_tree {
    padding: 0.2em;
    margin: 0;
    list-style-type: none;
    border: 1px solid #aaa;
    max-height: 50%;
    overflow: auto;
    background-color: white;
}

.EditPanel .block_tree ul {
    list-style-type: none;
    padding: 0;
    padding-left: 1em;
    padding-top: 0.3em;
}

.EditPanel .block_tree li {
    cursor: pointer;
    margin-bottom: 0.3em;
}

.EditPanel .block_tree .entry_label {
    padding: 0.1em 0.3em;
}

.EditPanel .block_tree .entry_label .qualifier_label {
    color: #555;
}

.EditPanel .block_tree .disabled_block .entry_label {
    color: #666 !important;
    font-style: italic;
}

.scripted .EditPanel .block_tree .entry_label {
    color: black;
    text-decoration: none;
    border: 1px solid white;
}

.EditPanel .block_tree li.highlighted > .entry_label {
    -webkit-border-radius: 3px;
    border: 1px solid #acc0d4;
    background-color: #c1d0df;
}

body.editing .block {
    outline: 2px solid rgb(200,200,200) !important;
    outline: 2px solid rgba(200,200,200,0.8) !important;
    background: rgb(230,230,230) !important;
    background: rgba(230,230,230,0.8) !important;
    cursor: pointer;
}

body.editing .highlighted_block {
    outline: 2px solid rgb(50,100,150) !important;
    outline: 2px solid rgba(50,100,150,0.4) !important;
    background: rgb(180,215,255) !important;
    background: rgba(50,100,150,0.3) !important;
}

