#-*- coding: utf-8 -*-
"""

@author:		Marc Pérez
@contact:		marc.perez@whads.com
@organization:	Whads/Accent SL
@since:			December 2009
"""
from cocktail.translations import translations

translations.define("googlesearch next",
    es = u"Siguiente",
    en = u"Next",
    fr = u"Suivante",
    ca = u"Següent"
)

translations.define("googlesearch previous",
    es = u"Anterior",
    en = u"Previous",
    fr = u"Dernière",
    ca = u"Anterior"
)
