/* Fixes issue here http://code.google.com/p/jcrop/issues/detail?id=1 */
.jcrop-holder {
    text-align: left;
    float: left;
}

.jcrop-vline, .jcrop-hline
{
	font-size: 0;
	position: absolute;
	background: white url('/resources/images/Jcrop.gif') top left repeat;
}
.jcrop-vline { height: 100%; width: 1px !important; }
.jcrop-hline { width: 100%; height: 1px !important; }
.jcrop-handle {
	font-size: 1px;
	width: 7px !important;
	height: 7px !important;
	border: 1px #eee solid;
	background-color: #333;
	*width: 9px;
	*height: 9px;
}

.jcrop-tracker { width: 100%; height: 100%; }

.custom .jcrop-vline,
.custom .jcrop-hline
{
	background: yellow;
}
.custom .jcrop-handle
{
	border-color: black;
	background-color: #C7BB00;
	-moz-border-radius: 3px;
	-webkit-border-radius: 3px;
}

.FileFieldsView .file_image {
    display: none;
}

.FileFieldsView .upload_info label {
    font-style: italic;
    float: left;
}

.FileFieldsView .upload_info .cut_check {
    float: left;
    width: 30px;
    margin-right: 10px;
    margin-top: 0;
}

.ui-dialog-overlay {
    background:url("/resources/images/overlay_background.png") repeat scroll 50% 50% #666666;
    opacity:0.5;
}
