#-*- coding: utf-8 -*-
u"""
(X)HTML templates for the CMS backend application.

@author:		Martí Congost
@contact:		marti.congost@whads.com
@organization:	Whads/Accent SL
@since:			July 2008
"""
from os import path as _path

