
.BasketIndicator {
    position: absolute;
    top: 3em;
    right: 0.5em;
    background-color: #e0d6bc;
    color: #463d26;
    padding: 0.4em;
    text-decoration: none;
    -webkit-box-shadow: 2px 2px 2px #9f957b;
}

.BasketIndicator:hover {
    text-decoration: underline;
}

