#!/usr/bin/env python
#-*- coding: utf-8 -*-
u"""

@author:		Martí Congost
@contact:		marti.congost@whads.com
@organization:	Whads/Accent SL
@since:			October 2008
"""
from woost.controllers.installer import Installer

def main():
    installer = Installer()
    installer.run()

if __name__ == "__main__":
    main()

