/* SendEmailView form
-----------------------------------------------------------------------------*/

.SendEmailView .item_body {
    padding: 1em;
}

.mailing_info .progress-bar {
    height: 20px;
    width: 500px;
    background-color: #eee;
    border: 1px solid #ccc;
    position: relative;
    margin: .7em 0;
}

.mailing_info .progress-text {
    text-align:center;
    width: 500px;
    color: #333;
    font-weight: bold;
    display: block;
    overflow: hidden;
    margin: 0 auto;
    position: absolute;
}

.mailing_info .progress {
    float: left;
    height: 20px;
    width: 0;
    background-color: #ccc;
}

.mailing_info .summary {
    height: 1.5em;
}

.mailing_test {
    margin: 1em 0;
    padding: 1em;
    background-color: #F2F0EB;
    border: 1px solid #E8E6E1;
    font-size: 80%;
}

.mailing_test p {
    padding-bottom: 1em;
}

