text {
    font-family: Arial !important;
}

.connector {
    stroke: black;
    stroke-width: 2px;
    stroke-dasharray: 3px 2px;
}

/* Transitions
-----------------------------------------------------------------------------*/
g.edge {
    cursor: pointer;
}

g.edge path, g.edge polygon {
    stroke: #484032 !important;
    stroke-width: 0.1em !important;
}

g.edge polygon {
    fill: #856b4b !important;
}

g.edge text {
    fill: #333 !important;
    font-size: 0.6em !important;
}

g.edge:hover path, g.edge:hover polygon {
    stroke: #3a3223 !important;
    stroke-width: 0.15em !important;
}

g.edge:hover polygon {
    fill: #d6c8b6 !important;
}

/* States
-----------------------------------------------------------------------------*/
g.node {
    cursor: pointer;
}

g.node ellipse {
    stroke: #cbad7a !important;
    stroke-width: 2px !important;
    fill: #eeddb6 !important;
    cursor: pointer;
}

g.node text {
    font-size: 0.85em !important;
    fill: #2f2b24 !important;
}

g.node:hover ellipse {
    stroke: #ba8f48 !important;
    fill: #e4d0a3 !important;
}

