
.OrderStep .steps_list {
    padding: 0;
    margin: 0;
    margin-top: 3em;
    overflow: hidden;
}

.OrderStep .steps_list li {
    float: left;
    list-style-position: inside;
    color: #888;
}

.OrderStep .steps_list li.current {
    color: black;
}

.OrderStep .steps_list li + li {
    margin-left: 1em;
    border-left: 1px solid #ccc;
    padding-left: 1em;
}

.OrderStep .step_content {
    clear: both;
    margin-top: 3em;
}

.OrderStep .step_buttons {
    margin-top: 3em;
}

.OrderStep .proceed_button {
    float: right;
}

