
.ImageEffectsEditor .effects_summary {
    padding-bottom: 0.8em;
    padding-top: 0.8em;
}

.ImageEffectsEditor .effects_summary span {
    font-size: 0.9em;
    color: #333;
    position: relative;
    top: -0.65em;
    left: 0.2em;
}

.scripted .ImageEffectsEditor input.input {
    display: none;
}

.image_effects_dialog {
    border: 1px solid #8a898c !important;
    -webkit-border-radius: 6px;
    -moz-border-radius: 6px;
    border-radius: 6px;
    background-color: #ddd !important;
}

.image_effects_dialog .dialog_header {
    font-weight: bold;
    color: #222;
    font-size: 1.25em;
    padding: 0.4em;
    background: -webkit-gradient(linear, left top, right top, from(#9e99a8), to(#cccad1));
    background: -moz-linear-gradient(top left, #9e99a8, #cccad1);
    -moz-border-radius-topleft: 4px;
    -moz-border-radius-topright: 4px;
    -webkit-border-top-left-radius: 4px;
    -webkit-border-top-right-radius: 4px;
    border-top-left-radius: 4px;
    border-top-right-radius: 4px;
    border-bottom: 1px solid #949297;
}

.image_effects_dialog .edited_image_viewport {
    overflow: scroll;
    border: 1px solid #999;
    position: absolute;
    left: 0.7em;
    right: 22em;
    top: 3.3em;
    bottom: 3.2em;
    background-color: white;
}

.image_effects_dialog .edit_box {
    position: absolute;
    top: 3.3em;
    right: 0.7em;
    bottom: 3.2em;
    width: 20.5em;
}

.image_effects_dialog .edit_box .edit_box_header {
    color: #222;
    font-weight: bold;
    font-size: 1em;
}

.image_effects_dialog .stack_box {
    max-height: 75%;
    overflow: auto;
}

.image_effects_dialog .image_effect_control {
    position: relative;
    border: 1px solid #999;
    margin-top: 0.4em;
    background-color: white;
    overflow: hidden;
    clear: both;
    -webkit-box-shadow: 2px 2px 2px #ccc;
    box-shadow: 2px 2px 2px #ccc;
}

.image_effects_dialog .image_effect_header {
    color: #333;
    font-weight: bold;
    font-size: 0.9em;
    padding-top: 0.2em;
    padding-left: 0.4em;
}

.image_effects_dialog .image_effect_header img {
    vertical-align: middle;
}

.image_effects_dialog .image_effect_container {
    padding: 0.4em;
    float: left;
    font-size: 0.9em;
}

.image_effects_dialog .image_effect_buttons {
    padding: 0.4em;
    text-align: right;
    float: right;
}

.image_effects_dialog .image_effect_buttons .remove_button {
    position: absolute;
    right: 0;
    top: 0;
    background: none;
    border: none;
    cursor: pointer;
}

.image_effects_dialog .image_effects_toolbar {
    border: 1px solid #999;
    margin-top: 0.4em;
    background-color: white;
    padding: 0.4em;
    -webkit-box-shadow: 2px 2px 2px #ccc;
    box-shadow: 2px 2px 2px #ccc;
}

.image_effects_dialog .image_effects_toolbar .label {
    font-size: 0.9em;
    margin-bottom: 0.3em;
}

.image_effects_dialog .image_effects_toolbar .image_effect_button {
    text-align: center;
    width: 4em;
    margin-right: 0.2em;
    margin-bottom: 0.2em;
    background: none;
    -webkit-border-radius: 6px;
    -moz-border-radius: 6px;
    border-radius: 6px;
    border: 1px solid white;
    cursor: pointer;
}

.image_effects_dialog .image_effects_toolbar button.image_effect_button:hover {
    background-color: #666a8f;
    border: 1px solid #585b73;
    color: white;
    outline: none;
}

.image_effects_dialog .image_effects_toolbar button.image_effect_button:focus {
    outline: 1px dotted #888;
}

.image_effects_dialog .image_effects_toolbar .image_effect_button span {
    display: block;
    text-align: center;
}

.image_effects_dialog .preview_button {
    margin-top: 1em;
    float: right;
}

.image_effects_dialog .status_bar {
    position: absolute;
    bottom: 0.7em;
    left: 0.7em;
    right: 22em;
}

.image_effects_dialog .buttons {
    position: absolute;
    bottom: 0.7em;
    width: 20.5em;
    right: 0.7em;
    text-align: right;
}

.image_effects_dialog .buttons button {
    width: 5em;
}

/* Brightness
-----------------------------------------------------------------------------*/
.image_effects_dialog .brightness_control input,
.image_effects_dialog .color_control input,
.image_effects_dialog .contrast_control input,
.image_effects_dialog .sharpness_control input {
    width: 5em;
}

/* Crop
-----------------------------------------------------------------------------*/
.image_effects_dialog .crop_control .x1,
.image_effects_dialog .crop_control .y1,
.image_effects_dialog .crop_control .x2,
.image_effects_dialog .crop_control .y2 {
    float: left;
}

.image_effects_dialog .crop_control .x1,
.image_effects_dialog .crop_control .x2 {
    margin-right: 0.5em;
}

.image_effects_dialog .crop_control .x2 {
    clear: left;
}

.image_effects_dialog .crop_control input {
    width: 3em;
}

/* Rotate
-----------------------------------------------------------------------------*/
.image_effects_dialog .rotate_control canvas {
    position: relative;
}

.image_effects_dialog .rotate_control input {
    position: relative;
    top: -1.2em;
    left: 0.4em;
    width: 5em;
}

/* Thumbnail
-----------------------------------------------------------------------------*/
.image_effects_dialog .thumbnail_control .relative_block {
    margin-top: 0.4em;
}

.image_effects_dialog .thumbnail_control .relative_block .option_controls input {
    width: 4em;
}

.image_effects_dialog .thumbnail_control .option_controls {
    padding-top: 0.6em;
    padding-left: 1.8em;
}

.image_effects_dialog .thumbnail_control .absolute_block .option_controls {
    clear: left;
    overflow: hidden;
    font-size: 0.9em;
}

.image_effects_dialog .thumbnail_control .absolute_block .option_controls div {
    clear: left;
}

.image_effects_dialog .thumbnail_control .absolute_block .option_controls label {
    width: 4em;
    float: left;
    padding-top: 0.3em;
}

.image_effects_dialog .thumbnail_control .absolute_block .option_controls input {
    width: 4em;
    float: left;
}

