
.SummaryOrderStep .checkout_summary {
    margin-top: 4em;
}

.SummaryOrderStep .basket,
.SummaryOrderStep .checkout_table {
    margin-bottom: 1em;
}

.SummaryOrderStep .checkout_table tr.group_header {
    display: none;
}

.SummaryOrderStep .checkout_table th {
    text-align: left;
    color: #333;
    padding-right: 1em;
}

.SummaryOrderStep .modify_basket_link,
.SummaryOrderStep .modify_checkout_link {
    float: right;
}

