
.BasketView .notice {
    background-color: #c7f5bb;
    border: 1px solid #90b487;
    padding: 0.5em;
    margin-bottom: 1em;
}

.BasketView .basket_table {
    border-collapse: collapse;
    width: 100%;
}

.BasketView .basket_table .purchase_option_label {
    font-weight: bold;
}

.BasketView .basket_table tr.odd {
    background-color: #fff;
}

.BasketView .basket_table tr.even {
    background-color: #eee;
}

.BasketView .basket_table th {
    background-image: -webkit-gradient(linear, left top, left bottom, from(white), to(#e5e5e5));
    border-bottom: 1px solid #ccc;
    color: #333;
}

.BasketView .basket_table tbody td {
    padding-top: 0.3em;
    padding-bottom: 0.3em;
}

.BasketView .basket_table th,
.BasketView .basket_table td {
    text-align: left;
    padding-right: 2em;
    vertical-align: center;
}

.BasketView .basket_table ul.purchase_options {
    margin: 0;
    margin-top: 0.5em;
    padding-left: 1.5em;
    font-size: 0.9em;
    color: #444;
}

.BasketView .basket_table .price_column,
.BasketView .basket_table .total_column {
    text-align: right;
}

.BasketView .basket_table .quantity_column input {
    width: 3em;
    text-align: right;
}

.BasketView .basket_table .quantity_column input {
    width: 3em;
    text-align: right;
}

.BasketView .basket_table .total_subtotal_cell {
    font-weight: bold;
}

.BasketView .basket_table .basket_table_total_cell {
    text-align: right;
    font-weight: bold;
}

.BasketView .basket_table .total_column {
    padding-right: 0;
}

.BasketView .basket_table .total_footer_cell {
    font-size: 1.2em;
    font-weight: bold;
}

.BasketView .product_image_link {
    float: left;
    margin-right: 1em;
}

.BasketView .discount .regular_price {
    text-decoration: line-through;
    font-size: 0.8em;
    color: #555;
    display: block;
}

