#-*- coding: utf-8 -*-
u"""

.. moduleauthor:: Martí Congost <marti.congost@whads.com>
"""
from cocktail.translations import translations

# TextFile
#------------------------------------------------------------------------------
translations.define("TextFile",
    ca = u"Fitxer de text",
    es = u"Fichero de texto",
    en = u"Text file"
)

translations.define("TextFile-plural",
    ca = u"Fitxers de text",
    es = u"Ficheros de texto",
    en = u"Text files"
)

translations.define("TextFile.title",
    ca = u"Títol",
    es = u"Título",
    en = u"Title"
)

translations.define("TextFile.content",
    ca = u"Contingut",
    es = u"Contenido",
    en = u"Content"
)

# TextFileController
#------------------------------------------------------------------------------
translations.define("woost.extensions.textfile.controller.title",
    ca = u"Controlador de fitxer de text",
    es = u"Controlador de fichero de texto",
    en = u"Text file controller"
)

