
.BackOfficeLayout .header,
.BackOfficeLayout .simple_search,
.BackOfficeLayout .search_results_message,
.BackOfficeLayout .toolbar_box,
.BackOfficeLayout .item_buttons,
.BackOfficeLayout .collapsed,
.BackOfficeLayout .content_view,
.BackOfficeLayout .content_type_box,
.BackOfficeLayout .user_views_bar {
    display: none;
}

.BackOfficeLayout ul.edit_path {
    padding: .5em 0;
}

.BackOfficeLayout form.body {
    padding: 1em 0;
}

.BackOfficeLayout .CalendarContentView h1 {
    display: block;
}

