#-*- coding: utf-8 -*-
"""

@author:		Martí Congost
@contact:		marti.congost@whads.com
@organization:	Whads/Accent SL
@since:			September 2009
"""
from cocktail.translations import translations

translations.define("Country",
    ca = u"País",
    es = u"País",
    en = u"Country"
)

translations.define("Country-plural",
    ca = u"Paisos",
    es = u"Países",
    en = u"Country"
)

translations.define("Country.country_name",
    ca = u"Nom",
    es = u"Nombre",
    en = u"Name"
)

translations.define("Country.iso_code",
    ca = u"Codi ISO",
    es = u"Código ISO",
    en = u"ISO code"
)

