#-*- coding: utf-8 -*-
u"""

.. moduleauthor:: Martí Congost <marti.congost@whads.com>
"""
from cocktail.translations import translations

# OpenGraphExtension
#------------------------------------------------------------------------------
translations.define("OpenGraphExtension.categories",
    ca = u"Categories",
    es = u"Categorías",
    en = u"Categories"
)

# Extensions to the Publishable model
#------------------------------------------------------------------------------
translations.define("Publishable.open_graph",
    ca = u"Integració amb OpenGraph/Facebook",
    es = u"Integración con OpenGraph/Facebook",
    en = u"OpenGraph/Facebook integration"
)

translations.define("Publishable.open_graph_enabled",
    ca = u"Publicar metadades per OpenGraph/Facebook",
    es = u"Publicar metadatos para OpenGraph/Facebook",
    en = u"Publish OpenGraph/Facebook metadata"
)

translations.define("Publishable.open_graph_type",
    ca = u"Tipus d'objecte",
    es = u"Tipo de objeto",
    en = u"Object type"
)

# OpenGraphCategory
#------------------------------------------------------------------------------
translations.define("OpenGraphCategory",
    ca = u"Categoria d'objecte OpenGraph",
    es = u"Categoría de objeto OpenGraph",
    en = u"OpenGraph object category"
)

translations.define("OpenGraphCategory-plural",
    ca = u"Categories d'objecte OpenGraph",
    es = u"Categorías de objeto OpenGraph",
    en = u"OpenGraph object categories"
)

translations.define("OpenGraphCategory.title",
    ca = u"Títol",
    es = u"Título",
    en = u"Title"
)

translations.define("OpenGraphCategory.code",
    ca = u"Codi",
    es = u"Code",
    en = u"Código"
)

translations.define("OpenGraphCategory.types",
    ca = u"Tipus",
    es = u"Tipos",
    en = u"Types"
)

# OpenGraphType
#------------------------------------------------------------------------------
translations.define("OpenGraphType",
    ca = u"Tipus d'objecte OpenGraph",
    es = u"Tipo de objeto OpenGraph",
    en = u"OpenGraph object type"
)

translations.define("OpenGraphType-plural",
    ca = u"Tipus d'objecte OpenGraph",
    es = u"Tipos de objeto OpenGraph",
    en = u"OpenGraph object types"
)

translations.define("OpenGraphType.title",
    ca = u"Títol",
    es = u"Título",
    en = u"Title"
)

translations.define("OpenGraphType.code",
    ca = u"Codi",
    es = u"Código",
    en = u"Code"
)

translations.define("OpenGraphType.category",
    ca = u"Categoria",
    es = u"Categoría",
    en = u"Category"
)

# Category and type titles
#------------------------------------------------------------------------------

# Activities
translations.define("opengraph.categories.activities",
    ca = u"Activitats",
    es = u"Actividades",
    en = u"Activities"
)

translations.define("opengraph.types.activity",
    ca = u"Activitat",
    es = u"Actividad",
    en = u"Activity"
)

translations.define("opengraph.types.sport",
    ca = u"Esport",
    es = u"Deporte",
    en = u"Sport"
)

# Businesses
translations.define("opengraph.categories.businesses",
    ca = u"Negocis",
    es = u"Negocios",
    en = u"Businesses"
)

translations.define("opengraph.types.bar",
    ca = u"Bar",
    es = u"Bar",
    en = u"Bar"
)

translations.define("opengraph.types.company",
    ca = u"Companyia",
    es = u"Compañía",
    en = u"Company"
)

translations.define("opengraph.types.cafe",
    ca = u"Cafè",
    es = u"Café",
    en = u"Cafe"
)

translations.define("opengraph.types.hotel",
    ca = u"Hotel",
    es = u"Hotel",
    en = u"Hotel"
)

translations.define("opengraph.types.restaurant",
    ca = u"Restaurant",
    es = u"Restaurante",
    en = u"Restaurant"
)

# Groups
translations.define("opengraph.categories.groups",
    ca = u"Grups",
    es = u"Grupos",
    en = u"Groups"
)

translations.define("opengraph.types.cause",
    ca = u"Causa",
    es = u"Causa",
    en = u"Cause"
)

translations.define("opengraph.types.sports_league",
    ca = u"Lliga esportiva",
    es = u"Liga deportiva",
    en = u"Sports league"
)

translations.define("opengraph.types.sports_team",
    ca = u"Equip esportiu",
    es = u"Equipo deportivo",
    en = u"Sports team"
)

# Organizations
translations.define("opengraph.categories.organizations",
    ca = u"Organitzacions",
    es = u"Organizaciones",
    en = u"Organizations"
)

translations.define("opengraph.types.band",
    ca = u"Grup musical",
    es = u"Grupo musical",
    en = u"Band"
)

translations.define("opengraph.types.government",
    ca = u"Govern",
    es = u"Gobierno",
    en = u"Government"
)

translations.define("opengraph.types.non_profit",
    ca = u"ONG",
    es = u"ONG",
    en = u"NGO"
)

translations.define("opengraph.types.school",
    ca = u"Escola",
    es = u"Escuela",
    en = u"School"
)

translations.define("opengraph.types.university",
    ca = u"Universitat",
    es = u"Universidad",
    en = u"University"
)

# People
translations.define("opengraph.categories.people",
    ca = u"Gent",
    es = u"Gente",
    en = u"People"
)

translations.define("opengraph.types.actor",
    ca = u"Actor",
    es = u"Actor",
    en = u"Actor"
)

translations.define("opengraph.types.athlete",
    ca = u"Atleta",
    es = u"Atleta",
    en = u"Athlete"
)

translations.define("opengraph.types.author",
    ca = u"Autor",
    es = u"Autor",
    en = u"Author"
)

translations.define("opengraph.types.director",
    ca = u"Director de cine",
    es = u"Director de cine",
    en = u"Director"
)

translations.define("opengraph.types.musician",
    ca = u"Músic",
    es = u"Músico",
    en = u"Musician"
)

translations.define("opengraph.types.politician",
    ca = u"Polític",
    es = u"Político",
    en = u"Politician"
)

translations.define("opengraph.types.profile",
    ca = u"Perfil",
    es = u"Perfil",
    en = u"Profile"
)

translations.define("opengraph.types.public_figure",
    ca = u"Figura pública",
    es = u"Figura pública",
    en = u"Public figure"
)

# Places
translations.define("opengraph.categories.places",
    ca = u"Llocs",
    es = u"Sitios",
    en = u"Places"
)

translations.define("opengraph.types.city",
    ca = u"Ciutat",
    es = u"Ciudad",
    en = u"City"
)

translations.define("opengraph.types.country",
    ca = u"País",
    es = u"País",
    en = u"Country"
)

translations.define("opengraph.types.landmark",
    ca = u"Punt d'interès",
    es = u"Punto de interés",
    en = u"Landmark"
)

translations.define("opengraph.types.state_province",
    ca = u"Província o regió",
    es = u"Provincia o región",
    en = u"State province"
)

# Products and entertainment
translations.define("opengraph.categories.products_and_entertainment",
    ca = u"Productes i entreteniment",
    es = u"Productos y entretenimiento",
    en = u"Products and entertainment"
)

translations.define("opengraph.types.album",
    ca = u"Àlbum",
    es = u"Álbum",
    en = u"Album"
)

translations.define("opengraph.types.book",
    ca = u"Llibre",
    es = u"Libro",
    en = u"Book"
)

translations.define("opengraph.types.drink",
    ca = u"Beguda",
    es = u"Bebida",
    en = u"Drink"
)

translations.define("opengraph.types.food",
    ca = u"Menjar",
    es = u"Comida",
    en = u"Food"
)

translations.define("opengraph.types.game",
    ca = u"Joc",
    es = u"Juego",
    en = u"Game"
)

translations.define("opengraph.types.movie",
    ca = u"Pel·lícula",
    es = u"Película",
    en = u"Movie"
)

translations.define("opengraph.types.product",
    ca = u"Producte",
    es = u"Producto",
    en = u"Product"
)

translations.define("opengraph.types.song",
    ca = u"Cançó",
    es = u"Canción",
    en = u"Song"
)

translations.define("opengraph.types.tv_show",
    ca = u"Programa de televisió",
    es = u"Programa de televisión",
    en = u"TV show"
)

# Websites
translations.define("opengraph.categories.websites",
    ca = u"Llocs web",
    es = u"Sitios web",
    en = u"Web sites"
)

translations.define("opengraph.types.article",
    ca = u"Article",
    es = u"Artículo",
    en = u"Article"
)

translations.define("opengraph.types.blog",
    ca = u"Blog",
    es = u"Blog",
    en = u"Blog"
)

translations.define("opengraph.types.website",
    ca = u"Lloc web",
    es = u"Sitio web",
    en = u"Web site"
)

