
/*div.content form.signup_form {*/
/*    background: #EEE;*/
/*    padding: 8px 3px 8px 3px;*/
/*    border: 2px solid #DDD;*/
/*}*/

div.content ul.error_box {
    font-size: 85%;
    color: black;
    border: 1px dotted rgb(200,160,120);
    background-color: rgb(245,230,215);
    padding: 0.5em;
}

    div.content ul.error_box li {
        list-style-type: none;
    }

    div.content ul.error_box li em {
        font-style: normal;
        font-weight: bold;
        color: rgb(135,35,10);
        font-style: italic;
    }

    div.content ul.error_box li + li {
        margin-top: 0.2em;
    }



div.content form.signup_form div.field {
    padding: 4px;
}

    div.content form.signup_form div.field label {
        float: left;
        line-height: 1.7em;
        width: 17em;
    }

    div.content form.signup_form div.field input {
        padding: 2px;
        width: 15.5em;
    }

    div.content form.signup_form div.buttons button {
        float: left;
        margin: 4px;
    }
