
.EditPanel a {
    color: #264dbd;
    text-decoration: underline;
}

.EditPanel {
    font-size: 12px;
    position: fixed;
    left: 0;
    bottom: 0;
    background-color: #f3f3f3;
    border: 1px solid #777;
    border-left: none;
    -webkit-border-top-right-radius: 6px;
    -webkit-box-shadow: 2px 2px 2px #666;
    z-index: 10000;
}

.EditPanel .panel_content {
    padding: 1em;
}

.EditPanel .edit_panel_section {
    margin-bottom: 1em;
}

.EditPanel .edit_panel_section_content {
    padding-left: 1em;
}

.EditPanel .edit_panel_title {
    font-weight: bold;
    margin-bottom: 0.2em;
    color: #222;
}

.EditPanel .close_panel_button {
    display: none;
    position: absolute;
    top: 2px;
    right: 2px;
    cursor: pointer;
    border: none;
    background: none;
    padding: 0;
}

.EditPanel .show_panel_button {
    border: none;
    background: none;
    padding: 0;
}

.scripted .EditPanel .panel_content {
    display: none;
}

.EditPanel.expanded .show_panel_button {
    display: none;
}

.EditPanel.expanded .panel_content,
.EditPanel.expanded .close_panel_button {
    display: block;
}

.EditPanel .EditLink {
    display: block;
    text-decoration: none;
}

.EditPanel .EditLink .label {
    text-decoration: underline;
}

