#-*- coding: utf-8 -*-
"""

@author:		Jordi Fernández
@contact:		jordi.fernandez@whads.com
@organization:	Whads/Accent SL
@since:			October 2009
"""
from cocktail.translations import translations

# Comment
#------------------------------------------------------------------------------
translations.define("Comment",
    ca = u"Comentari",
    es = u"Comentario",
    en = u"Comment"
)

translations.define("Comment-plural",
    ca = u"Comentaris",
    es = u"Comentarios",
    en = u"Comments"
)

translations.define("Comment.publishable",
    ca = u"Element comentat",
    es = u"Elemento comentado",
    en = u"Commented element"
)

translations.define("Comment.user_name",
    ca = u"Nom",
    es = u"Nombre",
    en = u"Name"
)

translations.define("Comment.user_email",
    ca = u"Correu electrònic",
    es = u"Correo electrónico",
    en = u"E-mail address"
)

translations.define("Comment.content",
    ca = u"Comentari",
    es = u"Comentario",
    en = u"Comment"
)

# Publishable
#------------------------------------------------------------------------------
translations.define("Publishable.allow_comments",
    ca = u"Accepta comentaris",
    es = u"Acepta comentarios",
    en = u"Comments allowed"
)

translations.define("Publishable.comments",
    ca = u"Comentaris",
    es = u"Comentarios",
    en = u"Comments"
)

