
.AddProductForm .product_added_buttons {
    margin-top: 1em;
    overflow: hidden;
}

.AddProductForm .product_added_back_button {
    float: left;
}

.AddProductForm .product_added_forward_button {
    float: right;
}

