
html,
body {
    background-color: white;
    /*background-color: rgb(190,200,215);*/
    margin: 0;
    padding: 0;
    font-family: Bitstream Vera Sans, Arial;
    font-size: 11pt;
}

a img {
    border: none;
}

/* Header
-----------------------------------------------------------------------------*/
.header {
    padding: 0.6em;
    height: 1.5em;
    background-color: rgb(245,245,245);
    background-color: #eceeef;
    background-repeat:repeat-y;
    background-image: url(../images/header_background.png);
    border-bottom: 1px solid rgb(180,190,200);
}

.header h1 {
    float: left;
    font-size: 125%;
    padding: 0;
    margin: 0;
}

.header h1 a {
    color: rgb(75,85,95);
    text-decoration: none;
}

/* Language selector
-----------------------------------------------------------------------------*/
.header .LanguageSelector {
    float: right;
    list-style-type: none;
    padding: 0;
    margin: 0;
    margin-top: 0.2em;
    margin-right: 4em;
    font-size: 9pt;
}

.header .LanguageSelector li {
    display: inline;
    padding: 0;
    margin: 0;
    margin-right: 0.5em;
}

.header .LanguageSelector a {
    text-decoration: none;
}

/* Active user session
-----------------------------------------------------------------------------*/
.header .identity {
    float: right;
    font-size: 0.8em;
    margin-top: 0.2em;
}

.header .identity strong {
    color: rgb(75,75,75);
}

.header .identity form {
    display: inline;
    margin: 0;
    padding: 0;
}

a,
.header .identity button {
    display: inline;
    font-size: inherit;
    background: none;
    border: none;
    color: rgb(50,80,110);
    margin: 0;
    padding: 0;
    cursor: pointer;
}

.header .identity button {
    margin-left: 0.7em;
}

/* Site menu
-----------------------------------------------------------------------------*/
.menu {
    clear: left;
    float: left;
    padding: 1em;
    padding-right: 2em;
    padding-top: 1.4em;
    margin: 0;
    border-top: none;
    border-right: 1px solid rgb(230,230,230);
    width: 10em;
}

.menu, .menu ul {
    list-style-type: none;
}

.menu ul {
    padding: 0;
    padding-left: 1.2em;
    padding-top: 0.4em;
}

.menu li + li {
    margin-top: 0.4em;
}

.menu a {
    text-decoration: none;
    color: rgb(100,120,140);
}

.menu .active {
    font-weight: bold;
}

.menu + .main {
    margin-left: 13em !important;
    border-left: 1px solid rgb(230,230,230);
}

/* Content
-----------------------------------------------------------------------------*/
.main {
    float: left;
    padding: 1.4em;
}

.main h2 {
    margin-top: 0;
    font-size: 110%;
    float: left;
}

.main .toolbar {
    float: right;
}

.main .toolbar .edit_link {
    background-repeat: no-repeat;
    background-image: url(../images/edit_small.png);
    padding-left: 1.5em;
    padding-bottom: 0.2em;
    font-size: 9pt;
}

.main .content {
    clear: both;
}

.fallback_language_notice {
    clear: both;
    padding: 0.4em;
    border: 1px solid #ed7;
    font-size: 0.9em;
    margin-bottom: 2em;
    background-color: #fe8;
    background-repeat: no-repeat;
    background-image: url(../images/fallback_language.png);
    background-position: 0.6em 0.4em;
    padding-left: 2.4em;
}

.footer {
    clear: left;
}

.error_box {
    color: black;
    border: 1px dotted rgb(200,160,120);
    background-color: rgb(245,230,215);
    padding: 0.5em;
    margin: 0;
    margin-bottom: 1em;
}

.error_box li {
    list-style-type: none;
}

.error_box li em {
    font-style: normal;
    font-weight: bold;
    color: rgb(135,35,10);
}

.Form .field_instance {
    clear: left;
    overflow: auto;
    margin-bottom: 0.3em;
}

.Form .field_instance > label {
    width: 12em;
    display: block;
    float: left;
    padding-top: 0.3em;
}

.Form .required_mark {
    font-weight: bold;
    color: #6478AA;
}

.Form .buttons {
    margin-top: 0.7em;
}

/* Errors
-----------------------------------------------------------------------------*/
.ErrorBox {
    color: black;
    border: 1px dotted rgb(200,160,120);
    background-color: rgb(245,230,215);
    padding: 0.5em;
    margin: 0;
    margin-bottom: 1em;
}

.ErrorBox li {
    list-style-type: none;
}

.ErrorBox li + li {
    margin-top: 0.2em;
}

.ErrorBox li em {
    font-style: normal;
    font-weight: bold;
    color: rgb(135,35,10);
}

/* Attachments list
-----------------------------------------------------------------------------*/
.attachments {
    list-style-type: none;
    padding: 0;
    margin: 1.4em 1em;
}

.attachments a {
    text-decoration: none;
    font-size: 10pt;
}

.attachments a img {
    vertical-align: middle;
}

.attachments a span {
    text-decoration: underline;
}

/* Login form
-----------------------------------------------------------------------------*/
.login_form {
    margin-top: 1.4em;
    width: 21em;
    background-color: rgb(240,240,240);
    border: 1px solid rgb(220,220,220);
    padding: 1em;
}

.login_form, .login_form * {
    font-size: 9pt;
}

.login_form label {
    clear: left;
    color: rgb(30,40,55);
    display: block;
    margin-bottom: 0.2em;
    font-weight: bold;
    color: rgb(50,50,50);
}

.login_form input {
	margin-bottom: 0.6em;
    width: 20.5em;
}

.login_form .buttons {
    margin-top: 0.4em;
    text-align: right;
}

.login_form .buttons input {
    width: auto;
}

.login_form a.forgot_password_link {
    margin-right: 0.5em;
}

