
.Catalog .product_entry {
    display: block;
    text-align: center;
    text-decoration: none;
    float: left;
    margin-right: 2em;
    margin-bottom: 2em;
}

.Catalog .product_image {
    margin: auto;
    margin-bottom: 0.5em;
    display: block;
}

.Catalog .product_entry:hover .product_label {
    text-decoration: underline;
}

