#-*- coding: utf-8 -*-
u"""

.. moduleauthor:: Martí Congost <marti.congost@whads.com>
"""
from cocktail.translations import translations

# Location
#------------------------------------------------------------------------------
translations.define("Location",
    ca = u"Ubicació",
    es = u"Ubicación",
    en = u"Location"
)

translations.define("Location-plural",
    ca = u"Ubicacions",
    es = u"Ubicaciones",
    en = u"Locations"
)

translations.define("Location.location_name",
    ca = u"Nom",
    es = u"Nombre",
    en = u"Name"
)

translations.define("Location.location_type",
    ca = u"Tipus d'ubicació",
    es = u"Tipo de ubicación",
    en = u"Location type"
)

translations.define("woost.extensions.locations.location_types.continent",
    ca = u"Continent",
    es = u"Continente",
    en = u"Continent"
)

translations.define("woost.extensions.locations.location_types.country",
    ca = u"País",
    es = u"País",
    en = u"Country"
)

translations.define(
    "woost.extensions.locations.location_types.autonomous_community",
    ca = u"Comunitat autònoma",
    es = u"Comunidad autónoma",
    en = u"Autonomous community"
)

translations.define(
    "woost.extensions.locations.location_types.province",
    ca = u"Província",
    es = u"Provincia",
    en = u"Province"
)

translations.define(
    "woost.extensions.locations.location_types.town",
    ca = u"Població",
    es = u"Población",
    en = u"Town"
)

translations.define("Location.code",
    ca = u"Codi",
    es = u"Código",
    en = u"Code"
)

translations.define("Location.parent",
    ca = u"Ubicació pare",
    es = u"Ubicación padre",
    en = u"Parent location"
)

translations.define("Location.locations",
    ca = u"Ubicacions contingudes",
    es = u"Ubicaciones contenidas",
    en = u"Child locations"
)

