/* Margin form */

    form {
        margin: 0;
    }


/* Login data and logout button alignment (6 & 7) */

    .BackOfficeLayout .identity {
    	vertical-align: middle;
    }

    .BackOfficeLayout .identity * {
    	vertical-align: middle;
    }

    .BackOfficeLayout .identity form button {
    	padding-top: 1px;
    }

    .translations_selector { display: none; }


/* No results module width fix (6 & 7) */

    .no_results {
        height: 1%;
    }


/* Main type selector margin correction (6 & 7) */

    .BackOfficeLayout .ContentTypeSelector {
        _margin-left: 0;
    }


/* Tab height correction (6 & 7) */

    .tabs button {
    	height: 2em !important;
    	_margin-bottom: -1px;
    }


/* Edit path height (6) */

    .BackOfficeLayout ul.edit_path {
        _height: 1.2em;
    }



/* Item count alignment */

    .BackOfficeLayout .item_count {
        float: right;
    }


/* Alignment correction for breadcrumb and filter dropdowns */

    .BackOfficeLayout .ContentTypePath .selector_content,
    .BackOfficeLayout .new_filter_selector .selector_content {
    	left: 0;
    	top: 20px;
    }

    .BackOfficeLayout .ContentTypeSelector .selector_content {
        left: 0 !important;
        top: 21px !important;
    }

    .content_type_box {
        margin-bottom: 1em;
    }

    .content_type_box .label {
        width: auto;
        float: left;
        _font-size: 12px;
    }

    .content_type_box div.label {
        _font-weight: bold;
        _margin-right: .5em;
    }

    .ActionBar {
        border: 1px solid red;
        margin: 0;
    }

    .BackOfficeLayout .toolbar_box {
        display: block;
        width: 100%;
        overflow: hidden;
        border-left: none;
        border-right: none;
    }

    table th div {
        width: auto !important;
    }

    .collection_display_container {
        position: relative;
        z-index: 1 !important;
    }

    .entry_label {
        display: block;
    }


/* Breadcrumb and dropdown selection overlay correction */

    .ContentTypeSelector {
    	position: relative;
    	z-index: 12;
    }

    .additional_actions_selector,
    .new_filter_selector {
        position: relative;
    	z-index: 11;
    }

    .new_toolbar_button {
        position: relative;
    	z-index: 10;
    }

    .new_toolbar_button .selector_content,
    .additional_actions_selector .selector_content {
        margin-top: -1px;
    }

    .translations_selector .selector_content {
        width: 8em;
        right: .6em;
    }
/* Content view selector */

    .content_view {
        line-height: 3em;
    }



    .BackOfficeLayout .CollectionView .filters {
        width: 100%;
        overflow: hidden;
        float: left;
    }

    .BackOfficeLayout .CollectionView .filters .new_filter_selector .label {
        background-repeat: no-repeat !important;
    }


/* Dropdown image alignment */

    .ContentTypeTree li a {
    	display: block;
    	_font-size: 12px;
    }


/* Title font correction */

    .BackOfficeLayout h2 {
        font-size: 100%;
    }


/* Fixed selector width */

    .new_toolbar_button,
    .additional_actions_selector {
        _width: 100px !important;
    }

/* Fixed selector */

.BackOfficeLayout .selector:hover a.label,
.BackOfficeLayout .unfolded a.label,
.BackOfficeLayout .unfolded:hover a.label {
    _background-color: rgb(250,250,250);
    _border: 1px solid rgb(190,200,210);
    _border-bottom-color: rgb(250,250,250);
    _z-index: 1001;
}

body.scripted .BackOfficeLayout .selector:hover a.label {
    _border-color: transparent;
    _background-color: transparent;
}

.BackOfficeLayout .selector:hover .selector_content,
body.scripted .BackOfficeLayout .selector.unfolded .selector_content,
body.scripted .BackOfficeLayout .selector.unfolded:hover .selector_content {
    display:block;
    z-index:1000;
}

.BackOfficeLayout .selector:hover a.label,
body.scripted .BackOfficeLayout .selector.unfolded a.label,
body.scripted .BackOfficeLayout .selector.unfolded:hover a.label {
    _background-color:#FAFAFA !important;
    _border-color:#BEC8D2 #BEC8D2 #FAFAFA !important;
    _border-style:solid !important;
    _border-width:1px !important;
    _z-index:1001 !important;
}

.BackOfficeLayout .ContentTable th .selector_content {
    top: 1.6em !important;
	margin-top: -1px;
    left: 0 !important;
}

.BackOfficeLayout .ContentTable th .selector a.label {
    white-space:nowrap;
	padding-right: 1.2em !important;
	display: inline !important;
	background:transparent url(../images/dropdown_arrow.png) no-repeat scroll right center;
}
º
.BackOfficeLayout .content_view_selector div.selected {
	_background-color:#EBF0F7;
	_border:1px solid #DCE1E8;
    _padding: .5em;
}

body.scripted .BackOfficeLayout .selector:hover .label {
	_background-color:transparent;
	_border-color:transparent;
}

.BackOfficeLayout .ContentTypeSelector .selected .entry_label {
	_font-weight:bold;
}

.BackOfficeLayout .ContentTypeSelector .entry_label {
	_color:black;
	_font-weight:bold;
	_margin-top: -1px;
	_padding:0.2em 1.1em 0.2em 0.5em;
}



.BackOfficeLayout .selector a.label {
	_background:transparent url(../images/dropdown_arrow.png) no-repeat scroll right 0.6em;
	_color:black;
	_cursor:pointer;
	_padding-left:0.2em;
	_padding-right:1em;
	_position:relative;
	_z-index:2;
}

.BackOfficeLayout .content_type_selector .label {
	_font-weight:normal !important;
}

.BackOfficeLayout .content_type_box .label,
.BackOfficeLayout .content_type_selector .label {
	_font-size:85%;
}

.BackOfficeLayout .ContentView .advanced_search {
	_padding-left:0.2em;
}


.BackOfficeLayout .simple_search {
	margin-left:2em;
}

.BackOfficeLayout .Pager .page_links a {
	_margin-left:0.5em;
}

.BackOfficeLayout .TreeContentView label {
    _margin-left: 1.5em;
}


.BackOfficeLayout .RadioSelector label,
.BackOfficeLayout .CheckList label,
.BackOfficeLayout .MemberList label {
    _display: inline;
    _margin-left: 0.2em;
}

.BackOfficeLayout .MemberList .content_type .label {
    _text-decoration: underline;
}

.BackOfficeLayout .content_type_box .label,
.BackOfficeLayout .content_type_selector .label {
    _font-size: 85%;
}

.BackOfficeLayout .content_type_box .label {
    _float: left;
    _padding: 0.15em 0;
    _margin-right: 0.6em;
    _font-weight: bold;
    _position: relative;
}

.BackOfficeHistoryView td.changes li {
    _margin-top: 0.3em;
}

.BackOfficeLayout .CollectionView .settings_box .selector_content div:first-child {
    _border-left: none;
}

.BackOfficeLayout .CollectionView .settings_box .selector_content div:last-child {
    _border-right: none;
}

.BackOfficeLayout .buttons button {
    margin-left: 0.8em;
}

.BackOfficeLayout .Form .fields table tbody tr td,
.BackOfficeLayout .Form fieldset table tbody tr td {
    padding-right: 1.5em;
    padding-bottom: 0.5em;
}


.BackOfficeLayout .Form .fields table.mceLayout tbody tr td,
.BackOfficeLayout .Form fieldset table.mceLayout tbody tr td {
    padding-right: 0;
    padding-bottom: 0;
}

.BackOfficeItemView .translations_selector {
    _width: 7.3em;
    display: block;
}

/*

.BackOfficeLayout .field .mceEditor .mceLayout {
	width: auto !important;
	border: 1px solid red;
}

.BackOfficeLayout .field .mceEditor .mceLayout a {
	margin: 0 !important;
	padding: 0 !important;
}

*/

/* Frame titles correction while editing inner elements of an item */

.BackOfficeLayout .stack_node > .label {
    height: 1%;
}

/* Remove height limitation for solving an overflow issue in toolbars */

.BackOfficeLayout .toolbar,
.BackOfficeLayout .data_controls,
.BackOfficeLayout .item_buttons,
.BackOfficeLayout .toolbar_box {
    overflow: hidden;
    height: auto;
}
