#-*- coding: utf-8 -*-
"""

@author:		Jordi Fernández
@contact:		jordi.fernandez@whads.com
@organization:	Whads/Accent SL
@since:			December 2009
"""
from cocktail.translations import translations
from cocktail.translations.strings import member_identifier

# Validation errors
#------------------------------------------------------------------------------
translations.define("woost.extensions.recaptcha.schemarecaptchas.ReCaptchaValidationError-instance",
    ca = u"Ho sentim, el CAPTCHA és erroni. Si us plau, intenti-ho de nou.",
    es = u"Lo sentimos, el CAPTCHA es erroneo. Por favor inténtelo de nuevo.",
    en = u"Sorry, you failed the CAPTCHA. Please try again."
)

