
.BackOfficeDiffView .differences {
    margin: 1em 0;
    font-size: 85%;
}

.BackOfficeDiffView .differences .check {
    width: 1em;
}

.BackOfficeDiffView .differences th {
    padding-bottom: 0.75em;
}

.BackOfficeDiffView .diff_add {
    color: rgb(0,125,0);
    font-weight: bold;
    background-color: rgb(230,255,210);
}

.BackOfficeDiffView .diff_sub {
    color: rgb(150,0,0);
    font-weight: bold;
    background-color: rgb(255,230,210);
}

.BackOfficeDiffView .diff_change {
    color: rgb(25,25,175);
    font-weight: bold;
    background-color: rgb(215,255,215);
}

.BackOfficeDiffView .language {
    color: rgb(75,75,75);
    font-style: italic;
    font-size: 85%;
}

.BackOfficeDiffView .difference_row + .difference_row > td {
    padding-top: 1em;
}

.BackOfficeDiffView .differences td,
.BackOfficeDiffView .differences th {
    text-align: left;
    vertical-align: top;
}

.BackOfficeDiffView .differences th + th,
.BackOfficeDiffView .differences td + td {
    padding-left: 1em;
}

.BackOfficeDiffView .diff_unit {
    height: 1.5em;
}

.BackOfficeDiffView .buttons {
    text-align: left;
    padding: 0;
    margin: 1em 0;
}
