
.ImageGallery ul {
    padding: 0;
    list-style-type: none;
    margin: 0;
}

.ImageGallery.thumbnails {
    overflow: hidden;
}

.ImageGallery.thumbnails .image_entry {
    float: left;
    margin: 0.5em;
}

.ImageGallery .image_link {
    display: block;
    text-decoration: none;
    text-align: center;
}

.ImageGallery .image_label {
    display: block;
    text-align: center;
    height: 1.5em;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
    -o-text-overflow: ellipsis;
}

.ImageGallery.slideshow .image {
    display: block;
    margin: auto;
}

.ImageGallery .slideshow_controls {
    display: block;
    position: absolute;
    left: 0;
    right: 0;
    bottom: 0px;
}

.ImageGallery .slideshow_controls a {
    position: absolute;
    bottom: 2px;
    padding: 5px;
    font-size: 0;
}

.ImageGallery .slideshow_controls .next_button {
    right: 2px;
}

.ImageGallery .slideshow_controls .previous_button {
    left: 2px;
}

body.modal {
    overflow: hidden;
}

.dialog-background {
    z-index: 10000;
    position: fixed;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    background-color: black;
    opacity: 0.85;
    filter: alpha(opacity=85);
}

.ImageGallery-dialog {
    z-index: 10001;
    border: none;
    position: fixed;
    top: 4%;
    background-color: white;
    -webkit-box-shadow: 3px 3px 3px #272727;
}

.ImageGallery-dialog button,
.ImageGallery-dialog .header,
.ImageGallery .slideshow_controls a {
    border: none;
    text-decoration: none;
    opacity: 0.7;
    filter: alpha(opacity=70);
    background-color: black;
    color: white;
    cursor: pointer;
    -moz-border-radius: 3px;
    -webkit-border-radius: 3px;
}

.ImageGallery-dialog .image_frame {
    position: relative;
}

.ImageGallery-dialog .footnote {
    padding: 0.2em;
    font-size: 0.85em;
}

.ImageGallery-dialog .image {
    display: block;
}

.ImageGallery-dialog img.image[tabindex="0"] {
    cursor: pointer;
}

.ImageGallery-dialog button:focus,
.ImageGallery-dialog button:hover,
.ImageGallery .slideshow_controls a:focus,
.ImageGallery .slideshow_controls a:hover {
    background-color: #313131;
    opacity: 0.8;
    filter: alpha(opacity=80);
}

.ImageGallery-dialog .header {
    position: absolute;
    left: 2px;
    top: 2px;
    padding: 0.2em;
}

.ImageGallery-dialog .index {
    margin-right: 0.4em;
    font-weight: bold;
}

.ImageGallery-dialog .close_button {
    position: absolute;
    top: 2px;
    right: 2px;
    font-size: 0;
}

.ImageGallery-dialog .next_button {
    position: absolute;
    bottom: 7px;
    right: 2px;
    padding: 5px;
    font-size: 0;
}

.ImageGallery-dialog .previous_button {
    position: absolute;
    bottom: 7px;
    left: 2px;
    padding: 5px;
    font-size: 0;
}

.ImageGallery-loading_sign {
    position: absolute;
    background-color: #aaa;
    border: 2px solid #999;
    font-weight: bold;
    padding: 0.8em;
    -moz-border-radius: 5px;
    -webkit-border-radius: 5px;
    -moz-box-shadow: 2px 2px 2px #444;
    -webkit-box-shadow: 2px 2px 2px #444;
    box-shadow: 2px 2px 2px #444;
    border-radius: 5px;
    z-index: 10002;
}

.ImageGallery-loading_sign .ball {
    position: absolute;
    background-color: #666;
    border: 2px solid #444;
    bottom: 2px;
}

