
.ProductPage .image_gallery {
    float: left;
    margin-bottom: 1em;
    margin-right: 1em;
}

.ProductPage .offers,
.ProductPage .offers li {
    list-style-type: none;
    display: block;
    padding: 0;
    margin: 0;
}

.ProductPage .offers {
    margin-top: 1em;
}

.ProductPage .add_product_form {
    clear: both;
    padding: 0.5em;
    background-color: #e0d6bc;
    margin-bottom: 2em;
}

.ProductPage .add_product_form_title {
    font-weight: bold;
    color: #463d26;
}

.ProductPage .add_product_form .quantity_field input {
    width: 4em;
}

.ProductPage .ErrorBox {
    margin-top: 1em;
}

