
.BackOfficeOrderView .insertion_point_explanation {
    margin-bottom: 1em;
}

.BackOfficeOrderView .position_selector .position_entry {
    margin-bottom: 0.4em;
    display: block;
}

.BackOfficeOrderView .position_selector button.position_entry {
    padding: 0;
    margin-left: -0.2em;
    border: none;
    background: none;
    cursor: pointer;
    color: #19426e;
}

.BackOfficeOrderView .position_selector .in_movement {
    color: #666;
}

.BackOfficeOrderView .position_selector .label {
    font-size: 0.9em;
}

