#-*- coding: utf-8 -*-
u"""
Woost is an object oriented, web based Content Management System, written
in python.

@author:		Martí Congost
@contact:		marti.congost@whads.com
@organization:	Whads/Accent SL
@since:			October 2008
"""

__version__ = "1.0.1"

from woost.application import Application
from woost.translations import strings

app = Application()

