
html,
body {
    background-color: rgb(190,200,215);
}

body {
    margin: 0;
    padding: 15px;
    text-align: center;
}

#wrapper {
  text-align: left;
  margin: auto;
  margin-top: 20%;
  width: 50%;
  font-family: Bitstream Vera Sans, Arial;
  font-size: 11pt;
  -moz-border-radius: 9px;
  border-radius: 9px;
  padding: 20px;
  border: 2px solid rgb(140,150,165);
  background-color: rgb(240,245,250);
}

p {
    margin-top: 0;
    margin-bottom: 15px;
}

form {
		width: 280px;
		margin-left: 15px;
    overflow: hidden;
}

label {
    clear: left;
    float: left;
    font-weight: bold;
    color: rgb(30,40,55);
    display: block;
    width: 100px;
    margin-bottom: 10px;
}

input {
		margin-bottom: 10px;
}

form .buttons input {
    float: none;
}

form .buttons {
    clear: left;
    margin-left: 100px;
}
