
.BackOfficeLayout .UserMemberForm .initialization_field .field_instance {
    width: 90%;
}

.BackOfficeLayout .UserMemberForm .initialization_field .CodeMirror-wrapping {
    width: 100% !important;
    height: 40em;
}

