
.Installer .navigation {
    display: none;
}

.Installer .Form .webserver_port_field .control,
.Installer .Form .database_port_field .control {
    width: 3.5em;
}

.Installer .Form .explanation {
    max-width: 35em;
    text-align: justify;
    padding-top: 0.6em;
    clear: both;
}

.Installer .success {
    padding: 0.4em;
}
