.ECommercePage .notification_box .notification {
    border: 1px solid rgb(220,210,190);
    background-color: rgb(240,240,210);
    padding: 0.4em;
    margin-bottom: 1em;
}

.ECommercePage .notification_box .notification .close_button {
    float: right;
    cursor: pointer;
}

.ECommercePage .notification_box .notification + .notification {
    margin-top: 0.4em;
}

.ECommercePage .notification_box .notification.success {
    border: 1px solid rgb(200,220,200);
    background-color: rgb(220,240,220);
}

.ECommercePage .notification_box .notification.success strong {
    color: rgb(20,80,20);
}

