#-*- coding: utf-8 -*-
u"""
Site specific translation strings.

@author:		Martí Congost
@contact:		marti.congost@whads.com
@organization:	Whads/Accent SL
@since:			December 2008
"""
import _PROJECT_MODULE_.translations.strings

